@@ -35,7 +35,7 @@ class SimpleDB:
         directory = site_data_dir("simpledb", appauthor=False)
         if not os.path.exists(directory):
             os.makedirs(directory)
-        self.__filename = os.path.join(directory, name + ".json.gzip")
+        self.__filename = os.path.join(directory, name + ".json.gz")
         self.__data = self.__load()
         self.__last_time_stored = datetime.now()
         logging.info("simple db: using " + self.__filename + " (" + str(len(self.__data)) + " entries)")
@@ -100,7 +100,7 @@ class SimpleDB:
         return {}
 
     def __store(self):
-        tempname = self.__filename + "." + str(range(10000)) + ".temp"
+        tempname = self.__filename + ".temp"
         try:
             self.__remove_expired()
         except Exception as e:
@@ -108,7 +108,7 @@ class SimpleDB:
         try:
             data = {name: self.__data[name].to_dict() for name in self.__data.keys()}
             with gzip.open(tempname, "wb") as file:
-                file.write(json.dumps(data).encode("UTF-8"))
+                file.write(json.dumps(data, indent=2).encode("UTF-8"))
             shutil.move(tempname, self.__filename)
         finally:
             os.remove(tempname) if os.path.exists(tempname) else None
